==> order-center-domain-3.0.0-CLOUD-DEV-20250513.063739-176-sources.jar: com/tydic/dyc/oc/model/order/sub/UocOrdLogisticsRela.java <==
package com.tydic.dyc.oc.model.order.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocOrdLogisticsRela
 * 说明:收货信息领域对象
 * 时间:2022-02-21 19:10
 * 作者:罗有
 **/
@Data
public class UocOrdLogisticsRela implements Serializable {
	private static final long serialVersionUID =  -4273257416454059216L;

	@DocField(value = "收货地址ID")
	private Long contactId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "联系人国家编号")
	private String contactCountryId;

	@DocField(value = "联系人国家名称")
	private String contactCountryName;

	@DocField(value = "联系人省份编号")
	private String contactProvinceId;

	@DocField(value = "联系人省份名称")
	private String contactProvinceName;

	@DocField(value = "联系人地市编号")
	private String contactCityId;

	@DocField(value = "联系人地市名称")
	private String contactCityName;

	@DocField(value = "联系人区县编号")
	private String contactCountyId;

	@DocField(value = "联系人区县名称")
	private String contactCountyName;

	@DocField(value = "联系人乡镇编号")
	private String contactTownId;

	@DocField(value = "联系人乡镇名称")
	private String contactTown;

	@DocField(value = "收货人地址")
	private String contactAddress;

	@DocField(value = "联系人公司")
	private String contactCompany;

	@DocField(value = "联系人名称")
	private String contactName;

	@DocField(value = "联系人固话")
	private String contactFixPhone;

	@DocField(value = "联系人邮件")
	private String contactEmail;

	@DocField(value = "联系人手机")
	private String contactMobile;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	/**
	 * 租户id
	 */
	private Long sysTenantId;
	/**
	 * 租户名称
	 */
	private String sysTenantName;

	/**
	 * 区号
	 */
	private String areaCode;

}

==> order-center-domain-3.1.0-CLOUD-DEV-20230625.084845-58-sources.jar: com/tydic/dyc/oc/model/order/sub/UocOrdLogisticsRela.java <==
package com.tydic.dyc.oc.model.order.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocOrdLogisticsRela
 * 说明:收货信息领域对象
 * 时间:2022-02-21 19:10
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocOrdLogisticsRela implements Serializable {
	private static final long serialVersionUID =  -4273257416454059216L;

	@DocField(value = "收货地址ID")
	private Long contactId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "联系人国家编号")
	private String contactCountryId;

	@DocField(value = "联系人国家名称")
	private String contactCountryName;

	@DocField(value = "联系人省份编号")
	private String contactProvinceId;

	@DocField(value = "联系人省份名称")
	private String contactProvinceName;

	@DocField(value = "联系人地市编号")
	private String contactCityId;

	@DocField(value = "联系人地市名称")
	private String contactCityName;

	@DocField(value = "联系人区县编号")
	private String contactCountyId;

	@DocField(value = "联系人区县名称")
	private String contactCountyName;

	@DocField(value = "联系人乡镇编号")
	private String contactTownId;

	@DocField(value = "联系人乡镇名称")
	private String contactTown;

	@DocField(value = "收货人地址")
	private String contactAddress;

	@DocField(value = "联系人公司")
	private String contactCompany;

	@DocField(value = "联系人名称")
	private String contactName;

	@DocField(value = "联系人固话")
	private String contactFixPhone;

	@DocField(value = "联系人邮件")
	private String contactEmail;

	@DocField(value = "联系人手机")
	private String contactMobile;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	

}
